# BRASSY: Build Release Assembler for Sane Software with YAML

There's only one [file](brassy/brassy.py).

The docs live here: https://biosafetylvl5.github.io/brassy/

## Install

``` bash
pip3 install brassy
```

or

``` bash
pip install brassy
```
